from revpayment.models import RedirectState
from revpayment.settings import api_settings


class BaseHandler:
    def __init__(self, order):
        self.order = order

    def get_state_meta(self, state):
        from revpayment.carts import Cart
        buyer = api_settings.BUYER_CLASS.objects.get(id=state.buyer_id)
        cart = Cart(buyer)
        return cart, buyer

    def on_payment_result(self):
        if self.order.payment_status == 'success':
            self.on_payment_success()

        elif self.order.payment_status == 'failure':
            self.on_payment_failure()

    def before_checkout(self, state):
        raise NotImplementedError

    def after_checkout(self, state):
        raise NotImplementedError

    def on_payment_success(self):
        raise NotImplementedError

    def on_payment_failure(self):
        raise NotImplementedError


class Handler(BaseHandler):
    def on_payment_success(self):
        return

    def on_payment_failure(self):
        return

    def before_checkout(self, state):
        return

    def after_checkout(self, state):
        return
